types Package
=============

:mod:`types` Package
--------------------

.. automodule:: numba.exttypes.types
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`extensiontype` Module
---------------------------

.. automodule:: numba.exttypes.types.extensiontype
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`methods` Module
---------------------

.. automodule:: numba.exttypes.types.methods
    :members:
    :undoc-members:
    :show-inheritance:

